/* --------------------------------------------------------------------------------------
 *  Copyright (C) 2004 Dallas Semiconductor Corporation, All Rights Reserved.
 * 
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the
 *  Software is furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included
 *  in all copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 *  MERCHANTABILITY,  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 *  IN NO EVENT SHALL DALLAS SEMICONDUCTOR BE LIABLE FOR ANY CLAIM, DAMAGES
 *  OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 *  OTHER DEALINGS IN THE SOFTWARE.
 * 
 *  Except as contained in this notice, the name of Dallas Semiconductor
 *  shall not be used except as stated in the Dallas Semiconductor
 *  Branding Policy.
 *
 *  Module:        gpio
 *  Description:   General Purpose I/O Convenience Functions
 *  Filename:      maxq2000_gpio.c
 *  Date:          October 13, 2004
 *  Version:       1.00
 *
 *  This file contains implementations for some basic convenience functions for 
 *  the GPIO available on the MAXQ2000.  It is not meant to be a complete library
 *  to support all the functionality available on the MAXQ2000's GPIO peripherals.
 *
 *  See the file 'maxq2000_gpio.h' for documentation on function usage.
 *
 * --------------------------------------------------------------------------------------
 */
#include <iomaxq200x.h>
#include "maxq2000_gpio.h"

void gpio_setoutputpin(int portnumber, int pinmask)
{
    switch (portnumber)
    {
        case 0 : PD0 = PD0 | pinmask;   break;
        case 1 : PD1 = PD1 | pinmask;   break;
        case 2 : PD2 = PD2 | pinmask;   break;
        case 3 : PD3 = PD3 | pinmask;   break;
        case 4 : PD4 = PD4 | pinmask;   break;
        case 5 : PD5 = PD5 | pinmask;   break;
        case 6 : PD6 = PD6 | pinmask;   break;
        case 7 : PD7 = PD7 | pinmask;   break;
    }
}


void gpio_setinputpin(int portnumber, int pinmask)
{
    switch (portnumber)
    {
        case 0 : PD0 = PD0 & ~pinmask;   break;
        case 1 : PD1 = PD1 & ~pinmask;   break;
        case 2 : PD2 = PD2 & ~pinmask;   break;
        case 3 : PD3 = PD3 & ~pinmask;   break;
        case 4 : PD4 = PD4 & ~pinmask;   break;
        case 5 : PD5 = PD5 & ~pinmask;   break;
        case 6 : PD6 = PD6 & ~pinmask;   break;
        case 7 : PD7 = PD7 & ~pinmask;   break;
    }
}

void gpio_setedgeselect(int interrupt_number, int risefall)
{
    int mask = 0x01 << (interrupt_number & 0x07);
    if (interrupt_number > 7)
    {
        if (risefall==RISING_EDGE)
            EIES1 = EIES1 & ~mask;
        else
            EIES1 = EIES1 | mask;
    }
    else
    {
        if (risefall==RISING_EDGE)
            EIES0 = EIES0 & ~mask;
        else
            EIES0 = EIES0 | mask;
    }
}

void gpio_setinterruptenable(int interrupt_number)
{
    int mask = 0x01 << (interrupt_number & 0x07);
    if (interrupt_number > 7)
    {
        EIE1 = EIE1 | mask;
    }
    else
    {
        EIE0 = EIE0 | mask;
    }
}

void gpio_clearinterruptenable(int interrupt_number)
{
    int mask = 0x01 << (interrupt_number & 0x07);
    if (interrupt_number > 7)
    {
        EIE1 = EIE1 & ~mask;
    }
    else
    {
        EIE0 = EIE0 & ~mask;
    }
}

