/* -----------------------------------------------------------------------------
 *  Copyright (C) 2004 Dallas Semiconductor Corporation, All Rights Reserved.
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 *  MERCHANTABILITY,  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 *  IN NO EVENT SHALL DALLAS SEMICONDUCTOR BE LIABLE FOR ANY CLAIM, DAMAGES
 *  OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 *  OTHER DEALINGS IN THE SOFTWARE.
 *
 *  Except as contained in this notice, the name of Dallas Semiconductor
 *  shall not be used except as stated in the Dallas Semiconductor
 *  Branding Policy.
 *
 *  Module:        maxq2000ev_1407
 *  Description:   Utility functions for communicating with the MAX1407 that
 *                 is located on the MAXQ2000 EV Kit.
 *  Filename:      maxq2000ev_1407.c
 *  Date:          November 2, 2004
 *  Version:       1.00
 *
 * ---------------------------------------------------------------------------*/

#include "maxq2000ev_1407.h"
#include <iomaxq200x.h>

unsigned int max1407_transmit(unsigned int ch)
{
    PO5 &= ~0x10;  /* Set /CS low.  */
    ch = spi_transmit(ch);
    PO5 |=  0x10;  /* Set /CS high. */
    return ch;
}

void max1407_init()
{
    unsigned int spidata;

    spi_setbaudrate(2100000UL, 12288000UL);
    spi_setclockpolarity(IDLE_LOW);
    spi_setclockphase(ACTIVE_EDGE);
    spi_setcharacterlength(LENGTH_8);
    spi_setmode(MASTER_MODE);
    spi_enable(1);

    spidata = MAX1407REG_RUN << 1;
    spidata |= MAX1407_WRITE_MASK;

    max1407_transmit(spidata);
}

unsigned int max1407_readregister(const unsigned char address, 
                                  const spi_size size)
{
    unsigned int spidata;

    spidata = address << 1;
    spidata |= MAX1407_READ_MASK;

    spi_setcharacterlength(LENGTH_8);
    max1407_transmit(spidata);

    spi_setcharacterlength(size);
    spidata = max1407_transmit(0);

    spi_setcharacterlength(LENGTH_8);
    return spidata;
}

void max1407_writeregister(const unsigned char address, 
                           const unsigned int value, 
                           const spi_size size)
{
    unsigned int spidata;

    spidata = address << 1;
    spidata |= MAX1407_WRITE_MASK;

    spi_setcharacterlength(LENGTH_8);
    max1407_transmit(spidata);

    spi_setcharacterlength(size);
    max1407_transmit(value);

    spi_setcharacterlength(LENGTH_8);
}

