/* -----------------------------------------------------------------------------
 *  Copyright (C) 2004 Dallas Semiconductor Corporation, All Rights Reserved.
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 *  MERCHANTABILITY,  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 *  IN NO EVENT SHALL DALLAS SEMICONDUCTOR BE LIABLE FOR ANY CLAIM, DAMAGES
 *  OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 *  OTHER DEALINGS IN THE SOFTWARE.
 *
 *  Except as contained in this notice, the name of Dallas Semiconductor
 *  shall not be used except as stated in the Dallas Semiconductor
 *  Branding Policy.
 *
 *  Module:        maxq2000ev_1407
 *  Description:   Utility functions for communicating with the MAX1407 that
 *                 is located on the MAXQ2000 EV Kit.
 *  Filename:      maxq2000ev_1407.c
 *  Date:          November 2, 2004
 *  Version:       1.00
 *
 * ---------------------------------------------------------------------------*/

#ifndef __MAXQ2000EV_1407__
#define __MAXQ2000EV_1407__

#include "maxq2000_spi.h"

#define MAX1407_READ_MASK 0xC0
#define MAX1407_WRITE_MASK 0x80

#define MAX1407REG_ADC          0x00
#define MAX1407REG_MUX          0x01
#define MAX1407REG_DATA         0x02
#define MAX1407REG_OFFSET       0x03
#define MAX1407REG_DAC1         0x04
#define MAX1407REG_DAC2         0x05
#define MAX1407REG_STATUS       0x06
#define MAX1407REG_ALBURST      0x08
#define MAX1407REG_ALSEC        0x09
#define MAX1407REG_ALMIN        0x0A
#define MAX1407REG_ALHOUR       0x0B
#define MAX1407REG_ALDAY        0x0C
#define MAX1407REG_ALSTATUS     0x0D
#define MAX1407REG_CLOCKCTL     0x0E
#define MAX1407REG_RTCBURST     0x0F
#define MAX1407REG_RTCSEC       0x10
#define MAX1407REG_RTCMIN       0x11
#define MAX1407REG_RTCHOUR      0x12
#define MAX1407REG_RTCDATE      0x13
#define MAX1407REG_RTCMONTH     0x14
#define MAX1407REG_RTCDAY       0x15
#define MAX1407REG_RTCYEAR      0x16
#define MAX1407REG_RTCCENTURY   0x17
#define MAX1407REG_POWER1       0x18
#define MAX1407REG_POWER2       0x19
#define MAX1407REG_SLEEP        0x1A
#define MAX1407REG_STANDBY      0x1B
#define MAX1407REG_IDLE         0x1C
#define MAX1407REG_RUN          0x1D

/******************************************************************************
 * Function:  max1407_init
 *
 * Sets the correct SPI modes for talking to the MAX1407, enables SPI, and
 * initializes the 1407.
 *
 * Input:     None.
 *
 * Output:    None.
 *
 ******************************************************************************/
void max1407_init(void);

/******************************************************************************
 * Function:  max1407_readregister
 *
 * Reads the contents of one of the MAX1407's registers.
 *
 * Input:     address  - Register to be read.
 *            size - Size of the register to be read (SPI_LENGTH_8 or
 *                   SPI_LENGTH_16).
 *
 * Output:    The value read.
 *
 ******************************************************************************/
unsigned int max1407_readregister(const unsigned char address,
                                  const spi_size size);

/******************************************************************************
 * Function:  max1407_writeregister
 *
 * Writes a new value to one of the MAX1407's registers.
 *
 * Input:     address  - Register to be written.
 *            value - New register contents.
 *            size - Size of the register to be read (SPI_LENGTH_8 or
 *                   SPI_LENGTH_16).
 *
 * Output:    None.
 *
 ******************************************************************************/
void max1407_writeregister(const unsigned char address,
                           const unsigned int value,
                           const spi_size size);

#endif
