/* --------------------------------------------------------------------------------------
 *  Copyright (C) 2004 Dallas Semiconductor Corporation, All Rights Reserved.
 * 
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the
 *  Software is furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included
 *  in all copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 *  MERCHANTABILITY,  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 *  IN NO EVENT SHALL DALLAS SEMICONDUCTOR BE LIABLE FOR ANY CLAIM, DAMAGES
 *  OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 *  OTHER DEALINGS IN THE SOFTWARE.
 * 
 *  Except as contained in this notice, the name of Dallas Semiconductor
 *  shall not be used except as stated in the Dallas Semiconductor
 *  Branding Policy.
 *
 *  Module:        lcd
 *  Description:   LCD Controller Convenience Functions Header File
 *  Filename:      maxq2000ev_lcd.h
 *  Date:          October 13, 2004
 *  Version:       1.00
 *
 *  Function declarations for the LCD Controller convenience library that goes along 
 *  with the IAR-MAXQ2000 demonstration software.
 *
 * --------------------------------------------------------------------------------------
 */
#ifndef __MAXQ2000EV_LCD__
#define __MAXQ2000EV_LCD__

#define LCD_PATTERN_0     0x03F
#define LCD_PATTERN_1     0x006
#define LCD_PATTERN_2     0x05B
#define LCD_PATTERN_3     0x04F
#define LCD_PATTERN_4     0x066
#define LCD_PATTERN_5     0x06D
#define LCD_PATTERN_6     0x07D
#define LCD_PATTERN_7     0x007
#define LCD_PATTERN_8     0x07F
#define LCD_PATTERN_9     0x067
#define LCD_PATTERN_A     0x077
#define LCD_PATTERN_B     0x07C
#define LCD_PATTERN_C     0x039
#define LCD_PATTERN_D     0x05E
#define LCD_PATTERN_E     0x079
#define LCD_PATTERN_F     0x071

/*******************************************************************************
 * Function: lcd_getlcddigit
 *
 * Returns the value needed to be written to an LCD register to correctly 
 * display the value of 'digit'.  This function works with the MAXQ2000 
 * Evaluation Kit LCD boards labeled "MAXQ2000-K01 Rev. B".
 * 
 * Input:    digit - number (0-15) to be displayed.  Values above 9 will be 
 *                   given hex display values
 * Output:   Value suitable to be written to an LCD register for display on the 
 *           Rev. B LCD board
 *
 ******************************************************************************/
int lcd_getlcddigit(int digit);

/*******************************************************************************
 * Function: lcd_shownumber
 *
 * Displays the number 'value' on the Rev. B LCD screen.  The LCD screen that 
 * comes with the MAXQ2000 EV Kit can only display numbers with magniture from 
 * 0 to 19999.  This function truncates values outside that range.  If the 
 * number is negative, the leading 'minus' sign is lit.  This function works
 * with the MAXQ2000 Evaluation Kit LCD boards labeled "MAXQ2000-K01 Rev. B".
 * 
 * Input:    value - number (-19999 to 19999) to be displayed on the LCD panel
 * Output:   None.  Value is written to the LCD registers.
 *
 * Note:     This function will not show leading zero's.  For a function to 
 *           show leading zero's, call the lcd_shownumber0 function.
 * 
 ******************************************************************************/
void lcd_shownumber(int value);

/*******************************************************************************
 * Function: lcd_shownumber0
 *
 * Displays the number 'value' on the Rev. B LCD screen.  The LCD screen that 
 * comes with the MAXQ2000 EV Kit can only display numbers with magniture from 
 * 0 to 19999.  This function truncates values outside that range.  If the 
 * number is negative, the leading 'minus' sign is lit.  This function works
 * with the MAXQ2000 Evaluation Kit LCD boards labeled "MAXQ2000-K01 Rev. B".
 * 
 * Input:    value - number (-19999 to 19999) to be displayed on the LCD panel
 * Output:   None.  Value is written to the LCD registers.
 *
 * Note:     This function WILL show leading zero's.  For a function to NOT
 *           show leading zero's, call the lcd_shownumber function.
 * 
 ******************************************************************************/
void lcd_shownumber0(int value);

/*******************************************************************************
 * Function: lcd_showtime
 *
 * Displays the time represented by the 'hours' and 'minutes' passed into the
 * function.  Values will be truncated to valid numbers from 0-99.  It is 
 * possible to pass invalid times to this function--this function will not
 * perform any data validation.  This function works with the MAXQ2000 
 * Evaluation Kit LCD boards labeled "MAXQ2000-K01 Rev. B".
 * 
 * Input:    hours - number of hours to display on the left of the colon
 *           minutes - number of minutes to display on the right of the colon
 * Output:   None.  Time is written to the LCD registers.
 *
 * Note:     This function could easily be used for a minutes:seconds as well.
 * 
 ******************************************************************************/
void lcd_showtime(int hours, int minutes);

/*******************************************************************************
 * Function: lcd_init
 *
 * Initializes the LCD display for the MAXQ2000 Evaluation Kit LCD boards 
 * labeled "MAXQ2000-K01 Rev. B".  The initialization factors assumed are as 
 * follows:
 * 
 *   Frame Frequency Bits = 7                   (FRM = 7)
 *   Clock Source         = High Frequency/128  (LCCS = 1)
 *   Duty Cycle           = Static              (DUTY = 0)
 *   Resistor Adjust      = 0                   (LRA = 0)
 *   LCD Power            = External            (POW = 1)
 *   Output Segments      = All                 (PCF = 0x0F)
 *   Operation Mode       = Normal              (OPM = 1)
 *   Display              = Enabled             (DPE = 1)
 * 
 * Input:    None.
 * Output:   None.
 *
 ******************************************************************************/
void lcd_init();

#endif
